X-Git-Url: https://git.saurik.com/bison.git/blobdiff_plain/71da68b3662b7169c58f8c5d4c0e89bc3caa31c4..55439a1cea2206bde793cbe1a8a0091207cc02dd:/src/symlist.h
diff --git a/src/symlist.h b/src/symlist.h
index 0bd4f3b0..03ffebef 100644
--- a/src/symlist.h
+++ b/src/symlist.h
@@ -34,8 +34,8 @@ typedef struct symbol_list
* \c <>.
*/
enum {
- SYMLIST_SYMBOL, SYMLIST_TYPE,
- SYMLIST_DEFAULT_TAGGED, SYMLIST_DEFAULT_TAGLESS
+ SYMLIST_SYMBOL,
+ SYMLIST_TYPE
} content_type;
union {
/**
@@ -46,7 +46,7 @@ typedef struct symbol_list
/**
* The semantic type iff symbol_list::content_type = SYMLIST_TYPE.
*/
- uniqstr type_name;
+ semantic_type *sem_type;
} content;
location location;
@@ -88,11 +88,6 @@ symbol_list *symbol_list_sym_new (symbol *sym, location loc);
/** Create a list containing \c type_name at \c loc. */
symbol_list *symbol_list_type_new (uniqstr type_name, location loc);
-/** Create a list containing a \c <*> at \c loc. */
-symbol_list *symbol_list_default_tagged_new (location loc);
-/** Create a list containing a \c <> at \c loc. */
-symbol_list *symbol_list_default_tagless_new (location loc);
-
/** Print this list.
\pre For every node \c n in the list, n->content_type =
@@ -118,9 +113,8 @@ uniqstr symbol_list_n_type_name_get (symbol_list *l, location loc, int n);
/* Check whether the node is a border element of a rule. */
bool symbol_list_null (symbol_list *node);
-/** Set the \c \%destructor or \c \%printer for \c node as \c code at
- \c loc. */
+/** Set the \c \%destructor or \c \%printer for \c node as \c cprops. */
void symbol_list_code_props_set (symbol_list *node, code_props_type kind,
- location loc, char const *code);
+ code_props const *cprops);
#endif /* !SYMLIST_H_ */